Field

Trait Field 

pub unsafe trait Field<Index> {
    type Type: ?Sized;
}
Projects the type of the field at Index in Self without regard for field privacy.

The Index parameter is any sort of handle that identifies the field; its definition is the obligation of the implementer.

Safety

Unsafe code may assume that this accurately reflects the definition of Self.

Required Associated Types

type Type: ?Sized

The type of the field at Index.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors